==> wandering-in-gpt-0.0.0.tar.gz: wandering-in-gpt-0.0.0/README.md <==
# Wandering in GPT: a role-play game

## How to

```bash
brew install python3
pip3 install wandering-in-gpt
wig
```

## A demo play in English

Narrator: it was in 1938 when Ettore Majorana, an Italian theoretical physicist who worked on
neutrino masses, had purchased a ticket to travel by ship from Palermo to Naples, he disappeared
under mysterious circumstances.Alice Wagner, an investigative journalist want to make the event
clear. So she set her journey to Italy...

Narrator: Alice arrived in Palermo and started her investigation. She went to the port and asked the
people there if they had seen Ettore Majorana.

Narrator: Suddenly, a young man named Tim Gray approached her. He said he had heard about her
investigation and wanted to help. Alice was surprised but welcomed the help.

Narrator: Tim told Alice that he had been working at the port for many years and had seen Ettore
Majorana the day he had purchased his ticket. He said he remembered seeing Ettore talking to a man
in a dark suit, but he couldn't remember who the man was.

Narrator: Alice thanked Tim for his help and decided to investigate further. She went to the local
newspaper office and asked to see any articles related to Ettore Majorana's disappearance. After
some searching, she found an article that mentioned a mysterious man in a dark suit who had been
seen with Ettore the day he disappeared.

Narrator: Alice was determined to find out who this man was. She decided to go to the police station
and ask if they had any information about the man. After some questioning, the police revealed that
the man in the dark suit was a known criminal who had been involved in several suspicious
activities.

Narrator: Alice was shocked to learn that Ettore had been seen with a criminal. She thanked the
police for their help and decided to investigate further. She went to the port and asked around for
anyone who had seen Ettore and the man in the dark suit together. After some searching, she found a
witness who had seen the two men together.

Narrator: The witness told Alice that he had seen Ettore and the man in the dark suit talking in a
secluded area of the port. He said that the man had been asking Ettore about something, but he
couldn't remember what it was.

Tim Gray: ...

## A demo play in Chinese

旁白: 颜回风尘仆仆从鲁国来到镐京，求见于老子

旁白: 颜回到了老子的门前，他拜倒在地，恭敬地说：“您好，老子大师，我是颜回，来自鲁国，请您指点迷津！”

旁白: 老子抬起头，看着颜回，笑了笑，说：“你来寻求真理，我可以教你，但你必须自己去发现，只有你自己才能找到真理。”

旁白: 颜回离开老子的门前，心中充满了希望，他知道自己必须努力去发现真理，而不是依赖别人的指点。他知道，只有自己才能找到真理。

旁白: 于是，颜回开始了他的旅程，他去探索，去发现，去求索真理。他走遍了中国，学习了各种学问，接触了各种思想，最终，他发现了真理，并将其传播到世界各地。

颜回: 这么多年了，我要回到镐京感谢老子当年的教导

颜回: 老子大师，我回来了

……

==> wandering-in-gpt-0.0.1.tar.gz: wandering-in-gpt-0.0.1/README.md <==
# Wandering in GPT: a role-play game

## How to

```bash
brew install python3
pip3 install wandering-in-gpt
wig
```

## A demo play in English

Narrator: it was in 1938 when Ettore Majorana, an Italian theoretical physicist who worked on
neutrino masses, had purchased a ticket to travel by ship from Palermo to Naples, he disappeared
under mysterious circumstances. Alice Wagner, an investigative journalist wants to make the event
clear. So she set her journey to Italy...

it was in 1938 when Ettore Majorana, an Italian theoretical physicist who worked on neutrino masses, had purchased a ticket to travel by ship from Palermo to Naples, he disappeared under mysterious circumstances. Alice Wagner, an investigative journalist wants to make the event clear. So she set her journey to Italy...

Narrator: Alice arrived in Palermo and started her investigation. She went to the port and asked the
people there if they had seen Ettore Majorana.

Narrator: Suddenly, a young man named Tim Gray approached her. He said he had heard about her
investigation and wanted to help. Alice was surprised but welcomed the help.

Narrator: Tim told Alice that he had been working at the port for many years and had seen Ettore
Majorana the day he had purchased his ticket. He said he remembered seeing Ettore talking to a man
in a dark suit, but he couldn't remember who the man was.

Narrator: Alice thanked Tim for his help and decided to investigate further. She went to the local
newspaper office and asked to see any articles related to Ettore Majorana's disappearance. After
some searching, she found an article that mentioned a mysterious man in a dark suit who had been
seen with Ettore the day he disappeared.

Narrator: Alice was determined to find out who this man was. She decided to go to the police station
and ask if they had any information about the man. After some questioning, the police revealed that
the man in the dark suit was a known criminal who had been involved in several suspicious
activities.

Narrator: Alice was shocked to learn that Ettore had been seen with a criminal. She thanked the
police for their help and decided to investigate further. She went to the port and asked around for
anyone who had seen Ettore and the man in the dark suit together. After some searching, she found a
witness who had seen the two men together.

Narrator: The witness told Alice that he had seen Ettore and the man in the dark suit talking in a
secluded area of the port. He said that the man had been asking Ettore about something, but he
couldn't remember what it was.

Tim Gray: ...

## A demo play in Chinese

旁白: 颜回辞别老师孔子，从鲁国来到镐京，一路风尘仆仆，到达后没有休息就直接求见老子，想问他世间的大道理。

旁白: 颜回到了老子的门前，他拜倒在地，恭敬地说：“您好，老子大师，我是颜回，来自鲁国，请您指点迷津！”

旁白: 老子抬起头，看着颜回，笑了笑，说：“你来寻求真理，我可以教你，但你必须自己去发现，只有你自己才能找到真理。”

旁白: 颜回离开老子的门前，心中充满了希望，他知道自己必须努力去发现真理，而不是依赖别人的指点。他知道，只有自己才能找到真理。

旁白: 于是，颜回开始了他的旅程，他去探索，去发现，去求索真理。他走遍了中国，学习了各种学问，接触了各种思想，最终，他发现了真理，并将其传播到世界各地。

颜回: 这么多年了，我要回到镐京感谢老子当年的教导

颜回: 老子大师，我回来了

……
